precision mediump float;
attribute vec4 Position;
attribute vec3 Normal;
attribute vec2 TextureCoord;

uniform mat4 Projection;
uniform mat4 Modelview;
uniform mat3 NormalMatrix;
uniform vec3 LightPosition;
uniform vec3 AmbientMaterial;
uniform vec3 DiffuseMaterial;
uniform vec3 SpecularMaterial;
uniform float Shininess;

varying vec4 DestinationColor;
varying vec2 TextureCoordOut;

//varying vec3 varNormals;
//varying vec3 v_LightVector;
//varying vec3 v_CameraVector;

void main(void)
{
    vec3 N = NormalMatrix * Normal;
    vec3 L = normalize(LightPosition);
    vec3 E = vec3(0, 0, 1);
    vec3 H = normalize(L + E);

    float df = max(0.0, dot(N, L));
    float sf = max(0.0, dot(N, H));
    sf = pow(sf, Shininess);

    vec3 color = AmbientMaterial + sf * SpecularMaterial + df * DiffuseMaterial;
    
    DestinationColor = vec4(color, 1.0);
    gl_Position = Projection * Modelview * Position;
    TextureCoordOut = TextureCoord;
    
//   varNormals = N;
//	 v_LightVector = L;
//	 v_CameraVector = E;
}
